AppColors class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- backgroundColorInputSearch ↔ HexColor
-
getter/setter pair
- colorDigitalpayeDegrade ↔ HexColor
-
getter/setter pair
- colorMTNDegrade ↔ HexColor
-
getter/setter pair
- colorOrangeDegrade ↔ HexColor
-
getter/setter pair
- colorPrimaryDegrade ↔ HexColor
-
getter/setter pair
- green ↔ HexColor
-
getter/setter pair
- greenApp ↔ HexColor
-
getter/setter pair
- lightprimaryColor ↔ HexColor
-
getter/setter pair
- orange ↔ HexColor
-
getter/setter pair
- red ↔ HexColor
-
getter/setter pair
Constants
- accentColor → const Color
- bgLightGrey → const Color
- black → const Color
- blackLight → const Color
- colorTexte → const Color
- compositionGroundColor → const Color
- dangerColor → const Color
- disabledColor → const Color
- errorColor → const Color
- errordColor → const Color
- grey_707070 → const Color
- greyFAF9FA → const Color
- greyFFD9D9D9 → const Color
- Grey
- primaryColor → const Color
- secondaryColor → const Color
- textSecondaire → const Color
- warningdColor → const Color
- white → const Color